"""Type stubs for poetry.console.commands.installer_command"""

from poetry.console.commands.command import Command
from poetry.installation.installer import Installer
from poetry.poetry import Poetry
from poetry.utils.env import Env

class InstallerCommand(Command):
    """Installer command stub."""
    def __init__(self) -> None: ...
    def handle(self) -> int: ...
    def reset_poetry(self) -> None: ...
    def get_installer(self) -> Installer: ...
    def set_installer(self, installer: Installer) -> None: ...
    def set_poetry(self, poetry: Poetry) -> None: ...
    def set_env(self, env: Env) -> None: ...
