"""Type stubs for poetry.console.commands.lock"""

from poetry.console.commands.installer_command import InstallerCommand
from poetry.poetry import Poetry
from poetry.utils.env import Env

class LockCommand(InstallerCommand):
    """Lock command stub."""
    def __init__(self) -> None: ...
    def handle(self) -> int: ...
    def set_poetry(self, poetry: Poetry) -> None: ...
    def set_env(self, env: Env) -> None: ...
    def update(self, lock: bool = True) -> None: ...
