"""Type stubs for poetry.console.commands.base"""

from typing import Any, Optional

class Command:
    poetry: Any
    io: Any
    env: Any

    def add_option(
        self, name: str, shortcut: Optional[str] = None, help: Optional[str] = None, **kwargs: Any
    ) -> None: ...
    def option(self, name: str) -> Any: ...
    def set_poetry(self, poetry: Any) -> None: ...
    def set_installer(self, installer: Any) -> None: ...
    def set_env(self, env: Any) -> None: ...
    def set_manager(self, manager: Any) -> None: ...
