"""Type stubs for poetry.console.commands.remove"""

from typing import List

from poetry.console.commands.installer_command import InstallerCommand
from poetry.poetry import Poetry
from poetry.utils.env import Env

class RemoveCommand(InstallerCommand):
    """Remove command stub."""
    def __init__(self) -> None: ...
    def handle(self) -> int: ...
    def set_poetry(self, poetry: Poetry) -> None: ...
    def set_env(self, env: Env) -> None: ...
    def remove_packages(self, packages: List[str]) -> None: ...
