"""Type stubs for poetry.console.commands.update"""

from typing import List, Optional

from poetry.console.commands.installer_command import InstallerCommand
from poetry.poetry import Poetry
from poetry.utils.env import Env

class UpdateCommand(InstallerCommand):
    """Update command stub."""
    def __init__(self) -> None: ...
    def handle(self) -> int: ...
    def set_poetry(self, poetry: Poetry) -> None: ...
    def set_env(self, env: Env) -> None: ...
    def update_packages(self, packages: Optional[List[str]] = None) -> None: ...
